
# Slot: node_types_column


Node type column name.

URI: [https://w3id.org/neat/ensmallenRunConfig__node_types_column](https://w3id.org/neat/ensmallenRunConfig__node_types_column)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
